/* UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include <string>
#include "../../standard_strategy.h"
#include "../../../toolinfo.h"
#include <moduleBasics/plot.h>
#include <moduleBasics/colors.h>

void StandardStrategy::generate_plots_dallara() {
    std::string pltDataFileName(rtIO->getCsvFilesDir() + "/ecological_assessment_climate_impact.csv");
    this->generate_plot_data_dallara(pltDataFileName);
    auto fig = matplot::figure(true);
    fig->size(1200, 1600);
    /* Define x axis */
    std::vector<uint16_t> time;
    for (uint16_t i = 0; i <= theClimateModelDallara.dallaraIOData->configuration.tmax; ++i) {
        time.push_back(i);
    }
    /* Read csv data */
    std::vector<double> emissions_CO2;
    std::vector<double> emissions_NOx;
    std::vector<double> emissions_H2O;
    std::vector<double> emissions_soot;
    std::vector<double> emissions_SO4;
    std::vector<double> ATR_CO2;
    std::vector<double> ATR_CH4;
    std::vector<double> ATR_O3L;
    std::vector<double> ATR_O3S;
    std::vector<double> ATR_H2O;
    std::vector<double> ATR_soot;
    std::vector<double> ATR_SO4;
    std::vector<double> ATR_AIC;
    std::vector<double> ATR_total;
    std::ifstream plotDataFile(pltDataFileName);
    if (!plotDataFile) {
        myRuntimeInfo->err << "File " << pltDataFileName << " can not be opened!" << std::endl;
    }
    std::vector<std::string> line_vector;
    std::string line;
    std::vector<std::string> line_data;
    int row = 0;
    while (std::getline(plotDataFile, line)) {
        line_vector.push_back(line);
        split(line_vector.back(), ';', &line_data);
        if (row > 1) {
            for (unsigned int column= 0; column < line_data.size(); column++) {
                if (column == 64) {
                        emissions_CO2.push_back(atof(line_data.at(column).c_str()));
                } else if (column == 65) {
                        emissions_NOx.push_back(atof(line_data.at(column).c_str()));
                } else if (column == 66) {
                        emissions_H2O.push_back(atof(line_data.at(column).c_str()));
                } else if (column == 67) {
                        emissions_soot.push_back(atof(line_data.at(column).c_str()));
                } else if (column == 68) {
                        emissions_SO4.push_back(atof(line_data.at(column).c_str()));
                } else if (column == 2) {
                        ATR_CO2.push_back(atof(line_data.at(column).c_str()));
                } else if (column == 3) {
                        ATR_CH4.push_back(atof(line_data.at(column).c_str()));
                } else if (column == 4) {
                        ATR_O3L.push_back(atof(line_data.at(column).c_str()));
                } else if (column == 5) {
                        ATR_O3S.push_back(atof(line_data.at(column).c_str()));
                } else if (column == 6) {
                        ATR_H2O.push_back(atof(line_data.at(column).c_str()));
                } else if (column == 7) {
                        ATR_soot.push_back(atof(line_data.at(column).c_str()));
                } else if (column == 8) {
                        ATR_SO4.push_back(atof(line_data.at(column).c_str()));
                } else if (column == 9) {
                        ATR_AIC.push_back(atof(line_data.at(column).c_str()));
                } else if (column == 1) {
                        ATR_total.push_back(atof(line_data.at(column).c_str()));
                }
            }
        }
        line_data.clear();
        row++;
    }
    plotDataFile.close();

    /* Subplot Emissions */
    auto ax1 = matplot::subplot(4, 2, 0);
    ax1->colororder(colors::unicado_to_matplot_colororder());
    matplot::plot(time, emissions_CO2)->line_width(1.25);
    matplot::hold(matplot::on);
    matplot::plot(time, emissions_NOx)->line_width(1.25);
    matplot::plot(time, emissions_H2O)->line_width(1.25);
    matplot::plot(time, emissions_soot)->line_width(1.25);
    matplot::plot(time, emissions_SO4)->line_width(1.25);
    matplot::hold(matplot::off);
    matplot::title("Emissions");
    ax1->xlabel("Time [yr]");
    ax1->ylabel("Emissions  [kg]");
    double y_max = std::max({*std::max_element(emissions_CO2.begin(), emissions_CO2.end()),
                            *std::max_element(emissions_NOx.begin(), emissions_NOx.end()),
                            *std::max_element(emissions_H2O.begin(), emissions_H2O.end()),
                            *std::max_element(emissions_soot.begin(), emissions_soot.end()),
                            *std::max_element(emissions_SO4.begin(), emissions_SO4.end())});
    ax1->ylim({ACCURACY_LOW, y_max*5.});
    ax1->y_axis().scale(matplot::axis_type::axis_scale::log);
    auto lgdEmissions = matplot::legend({"CO2", "NOx", "H2O", "Soot", "SO4"});

    /* Legend entries */
    std::vector<std::string> legend_labels = {"Total", "CO2", "CH4", "O3L", "O3S", "H2O", "Soot", "SO4", "AIC"};

    /* Subplot ATR*/
    auto ax2 = matplot::subplot(4, 2, 1);
    ax2->colororder(colors::unicado_to_matplot_colororder());
    matplot::plot(time, ATR_total)->line_width(1.25);
    matplot::hold(matplot::on);
    matplot::plot(time, ATR_CO2)->line_width(1.25);
    matplot::plot(time, ATR_CH4)->line_width(1.25);
    matplot::plot(time, ATR_O3L)->line_width(1.25);
    matplot::plot(time, ATR_O3S)->line_width(1.25);
    matplot::plot(time, ATR_H2O)->line_width(1.25);
    matplot::plot(time, ATR_soot)->line_width(1.25);
    matplot::plot(time, ATR_SO4)->line_width(1.25);
    matplot::plot(time, ATR_AIC)->line_width(1.25);
    matplot::hold(matplot::off);
    matplot::title("Average Temperature Response");
    ax2->xlabel("Time [yr]");
    ax2->ylabel("ATR [K]");
    auto lgd_ATR = matplot::legend(legend_labels);
    lgd_ATR->num_columns(2);
    lgd_ATR->location(matplot::legend::general_alignment::topright);

    /* Subplot RF */
    auto ax3 = matplot::subplot(4, 2, 2);
    ax3->colororder(colors::unicado_to_matplot_colororder());
    matplot::plot(time, theClimateModelDallara.total_annual_radiative_forcing)->line_width(1.25);
    matplot::hold(matplot::on);
    matplot::plot(time, theClimateModelDallara.annual_radiative_forcing.at(0))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_radiative_forcing.at(1))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_radiative_forcing.at(2))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_radiative_forcing.at(3))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_radiative_forcing.at(4))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_radiative_forcing.at(5))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_radiative_forcing.at(6))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_radiative_forcing.at(7))->line_width(1.25);
    matplot::hold(matplot::off);
    matplot::title("Radiative Forcing");
    ax3->xlabel("Time [yr]");
    ax3->ylabel("RF [W/m^2]");
    auto lgd_RF = matplot::legend(legend_labels);
    lgd_RF->num_columns(2);
    lgd_RF->location(matplot::legend::general_alignment::topright);

    /* Subplot RF modified */
    auto ax4 = matplot::subplot(4, 2, 3);
    ax4->colororder(colors::unicado_to_matplot_colororder());
    matplot::plot(time, theClimateModelDallara.total_annual_normalized_radiative_forcing)->line_width(1.25);
    matplot::hold(matplot::on);
    matplot::plot(time, theClimateModelDallara.annual_normalized_radiative_forcing.at(0))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_normalized_radiative_forcing.at(1))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_normalized_radiative_forcing.at(2))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_normalized_radiative_forcing.at(3))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_normalized_radiative_forcing.at(4))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_normalized_radiative_forcing.at(5))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_normalized_radiative_forcing.at(6))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_normalized_radiative_forcing.at(7))->line_width(1.25);
    matplot::title("Normalized Radiative Forcing");
    matplot::hold(matplot::off);
    ax4->xlabel("Time [yr]");
    ax4->ylabel("RF normalized [-]");
    auto lgd_nRF = matplot::legend(legend_labels);
    lgd_nRF->num_columns(2);
    lgd_nRF->location(matplot::legend::general_alignment::topright);

    /* Subplot temperature change */
    auto ax5 = matplot::subplot(4, 2, 4);
    ax5->colororder(colors::unicado_to_matplot_colororder());
    matplot::plot(time, theClimateModelDallara.total_annual_temperature_change)->line_width(1.25);
    matplot::hold(matplot::on);
    matplot::plot(time, theClimateModelDallara.annual_temperature_change.at(0))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_temperature_change.at(1))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_temperature_change.at(2))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_temperature_change.at(3))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_temperature_change.at(4))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_temperature_change.at(5))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_temperature_change.at(6))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_temperature_change.at(7))->line_width(1.25);
    matplot::hold(matplot::off);
    matplot::title("Temperature Change");
    ax5->xlabel("Time [yr]");
    ax5->ylabel("Temperature Change [K]");
    auto lgd_T = matplot::legend(legend_labels);
    lgd_T->num_columns(2);
    lgd_T->location(matplot::legend::general_alignment::topright);

    /* Subplot temperature change weighted*/
    auto ax6 = matplot::subplot(4, 2, 5);
    ax6->colororder(colors::unicado_to_matplot_colororder());
    matplot::plot(time, theClimateModelDallara.total_annual_temperature_change_weighted)->line_width(1.25);
    matplot::hold(matplot::on);
    matplot::plot(time, theClimateModelDallara.annual_temperature_change_weighted.at(0))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_temperature_change_weighted.at(1))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_temperature_change_weighted.at(2))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_temperature_change_weighted.at(3))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_temperature_change_weighted.at(4))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_temperature_change_weighted.at(5))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_temperature_change_weighted.at(6))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_temperature_change_weighted.at(7))->line_width(1.25);
    matplot::hold(matplot::off);
    matplot::title("Weighted Temperature Change");
    ax6->xlabel("Time [yr]");
    ax6->ylabel("Weighted Temperature Change [K]");
    auto lgd_T_w = matplot::legend(legend_labels);
    lgd_T_w->num_columns(2);
    lgd_T_w->location(matplot::legend::general_alignment::topright);

    /* Subplot AGWP */
    auto ax7 = matplot::subplot(4, 2, 6);
    ax7->colororder(colors::unicado_to_matplot_colororder());
    matplot::plot(time, theClimateModelDallara.total_annual_agwp)->line_width(1.25);
    matplot::hold(matplot::on);
    matplot::plot(time, theClimateModelDallara.annual_agwp.at(0))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_agwp.at(1))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_agwp.at(2))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_agwp.at(3))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_agwp.at(4))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_agwp.at(5))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_agwp.at(6))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_agwp.at(7))->line_width(1.25);
    matplot::hold(matplot::off);
    matplot::title("Absolute Global Warming Potential");
    ax7->xlabel("Time [yr]");
    ax7->ylabel("AGWP [W/m^2]");
    auto lgd_AGWP = matplot::legend(legend_labels);
    lgd_AGWP->num_columns(2);
    lgd_AGWP->location(matplot::legend::general_alignment::topright);

    /* Subplot AGTP */
    auto ax8 = matplot::subplot(4, 2, 7);
    ax8->colororder(colors::unicado_to_matplot_colororder());
    matplot::plot(time, theClimateModelDallara.total_annual_agtp)->line_width(1.25);
    matplot::hold(matplot::on);
    matplot::plot(time, theClimateModelDallara.annual_agtp.at(0))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_agtp.at(1))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_agtp.at(2))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_agtp.at(3))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_agtp.at(4))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_agtp.at(5))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_agtp.at(6))->line_width(1.25);
    matplot::plot(time, theClimateModelDallara.annual_agtp.at(7))->line_width(1.25);
    matplot::hold(matplot::off);
    matplot::title("Absolute Global Temperature Potential");
    ax8->xlabel("Time [yr]");
    ax8->ylabel("AGTP [K]");
    auto lgd_AGTP = matplot::legend(legend_labels);
    lgd_AGTP->num_columns(2);
    lgd_AGTP->location(matplot::legend::general_alignment::topright);
    /* Save plot */
    std::string plotFilePath = rtIO->getPlotDir() + "/" + std::string(TOOL_NAME) + "_climate_impact.svg";
    matplot::save(plotFilePath);
}

void StandardStrategy::generate_plot_data_dallara(const std::string& pltDataFile) {
    std::ofstream plot;
    plot.open(pltDataFile.c_str());
    if (!plot) {
        myRuntimeInfo->err << pltDataFile + " could not be opened!" << std::endl;
        exit(1);
    } else {
        plot << "# " + pltDataFile << std::endl;
        /*Adjust data structure: **/
        plot << "# (1) Year; (2) ATR Total [K]; (3) ATR CO2 [K]; (4) ATR CH4 [K]; (5) ATR O3L [K]; (6) ATR O3S [K]; (7) ATR H2O [K]; "
                " (8) ATR Soot [K]; (9) ATR SO4 [K]; (10) ATR AIC [K]; (11) Radiative Forcing Total [W/m^2]; (12) Radiative Forcing CO2 [W/m^2];"
                " (13) Radiative Forcing CH4 [W/m^2]; (14) Radiative Forcing O3L [W/m^2]; (15) Radiative Forcing O3S [W/m^2]; (16) Radiative Forcing H2O [W/m^2];"
                " (17) Radiative Forcing Soot [W/m^2]; (18) Radiative Forcing SO4 [W/m^2]; (19) Radiative Forcing AIC [W/m^2]; "
                " (20) Normalized Radiative Forcing Total [-]; (21) Normalized Radiative Forcing CO2 [-]; (22) Normalized Radiative Forcing CH4 [-];"
                " (23) Normalized Radiative Forcing O3L [-]; (24) Normalized Radiative Forcing O3S [-]; (25)Normalized Radiative Forcing H2O [-];"
                " (26) Normalized Radiative Forcing Soot [-]; (27) Normalized Radiative Forcing SO4 [-]; (28)Normalized Radiative Forcing AIC [-];"
                " (29) AGWP Total [W/m^2]; (30) AGWP CO2 [W/m^2]; (31) AGWP CH4 [W/m^2]; (32) AGWP O3L [W/m^2]; (33) AGWP O3S [W/m^2]; (34) AGWP H2O [W/m^2];"
                " (35) AGWP Soot [W/m^2]; (36) AGWP SO4 [W/m^2]; (37) AGWP AIC [W/m^2]; (38) Temperature Change Total [K]; (39) Temperature Change CO2 [K];"
                " (40) Temperature Change CH4 [K]; (41) Temperature Change O3L [K]; (42) Temperature Change O3S [K]; (43) Temperature Change H2O [K];"
                " (44) Temperature Change Soot [K]; (45) Temperature Change SO4 [K]; (46) Temperature Change AIC [K]; (47) Temperature Change Weighted Total [K];"
                " (48) Temperature Change Weighted CO2 [K]; (49) Temperature Change Weighted CH4 [K]; (50) Temperature Change Weighted O3L[K];"
                " (51) Temperature Change Weighted O3S [K]; (52) Temperature Change Weighted_H2O [K]; (53) Temperature Change Weighted Soot [K]; "
                " (54) Temperature Change Weighted SO4 [K]; (55) Temperature Change Weighted AIC [K]; (56) AGTP Total [K]; (57) AGTP CO2 [K];"
                " (58) AGTP CH4 [K]; (59) AGTP O3L [K]; (60) AGTP O3S [K]; (61) AGTP H2O [K]; (62) AGTP Soot [K]; (63) AGTP SO4 [K];"
                " (64) AGTP SO4 [K]; (65) Emissions per Year CO2 [kg]; (66) Emissions per Year NOx [kg]; (67) Emissions per Year H2O [kg]; (68) Emissions per Year Soot [kg];"
                " (69) Emissions per Year SO4 [kg]; (70) Nautical Miles per Year for AIC [NMi];  " << std::endl;
        std::vector<double> ATRyearTmp;
        std::vector<double> ATRyear_CO2Tmp;
        std::vector<double> ATRyear_CH4Tmp;
        std::vector<double> ATRyear_O3LTmp;
        std::vector<double> ATRyear_O3STmp;
        std::vector<double> ATRyear_H2OTmp;
        std::vector<double> ATRyear_sootTmp;
        std::vector<double> ATRyear_SO4Tmp;
        std::vector<double> ATRyear_AICTmp;
        std::vector<double> e_year_CO2Tmp;
        std::vector<double> e_year_NOxTmp;
        std::vector<double> e_year_H2OTmp;
        std::vector<double> e_year_sootTmp;
        std::vector<double> e_year_SO4Tmp;
        std::vector<double> e_year_AICTmp;
        for (uint16_t t = 0; t <= theClimateModelDallara.dallaraIOData->configuration.tmax; t++) {
            double sigma = 0;
            if (t < theClimateModelDallara.dallaraIOData->duration_operation) {
                sigma = 1;
            } else {
                sigma = 0;
            }
            /* write out the ATR values */
            ATRyearTmp.push_back(0.);
            ATRyear_CO2Tmp.push_back(0.);
            ATRyear_CH4Tmp.push_back(0.);
            ATRyear_O3LTmp.push_back(0.);
            ATRyear_O3STmp.push_back(0.);
            ATRyear_H2OTmp.push_back(0.);
            ATRyear_sootTmp.push_back(0.);
            ATRyear_SO4Tmp.push_back(0.);
            ATRyear_AICTmp.push_back(0.);
            ATRyearTmp.back() = sigma * theClimateModelDallara.dallaraIOData->ATR;
            ATRyear_CO2Tmp.back() = sigma * theClimateModelDallara.ATR_per_year.at(0);
            ATRyear_CH4Tmp.back() = sigma * theClimateModelDallara.ATR_per_year.at(1);
            ATRyear_O3LTmp.back() = sigma * theClimateModelDallara.ATR_per_year.at(2);
            ATRyear_O3STmp.back() = sigma * theClimateModelDallara.ATR_per_year.at(3);
            ATRyear_H2OTmp.back() = sigma * theClimateModelDallara.ATR_per_year.at(4);
            ATRyear_sootTmp.back() = sigma * theClimateModelDallara.ATR_per_year.at(5);
            ATRyear_SO4Tmp.back() = sigma * theClimateModelDallara.ATR_per_year.at(6);
            ATRyear_AICTmp.back() = sigma * theClimateModelDallara.ATR_per_year.at(7);
            /* Write out the annual emission values */
            e_year_CO2Tmp.push_back(0.);
            e_year_NOxTmp.push_back(0.);
            e_year_H2OTmp.push_back(0.);
            e_year_sootTmp.push_back(0.);
            e_year_SO4Tmp.push_back(0.);
            e_year_AICTmp.push_back(0.);
            e_year_CO2Tmp.back() = sigma * theClimateModelDallara.emissions_per_year.at(0);
            e_year_NOxTmp.back() = sigma * theClimateModelDallara.emissions_per_year.at(1);
            e_year_H2OTmp.back() = sigma * theClimateModelDallara.emissions_per_year.at(4);
            e_year_sootTmp.back() = sigma * theClimateModelDallara.emissions_per_year.at(5);
            e_year_SO4Tmp.back() = sigma * theClimateModelDallara.emissions_per_year.at(6);
            e_year_AICTmp.back() = sigma * theClimateModelDallara.emissions_per_year.at(7);
            plot << t << "; " <<
                 ATRyearTmp.at(t) << ";" <<
                 ATRyear_CO2Tmp.at(t) << ";" <<
                 ATRyear_CH4Tmp.at(t) << ";" <<
                 ATRyear_O3LTmp.at(t) << ";" <<
                 ATRyear_O3STmp.at(t) << ";" <<
                 ATRyear_H2OTmp.at(t) << ";" <<
                 ATRyear_sootTmp.at(t) << ";" <<
                 ATRyear_SO4Tmp.at(t) << ";" <<
                 ATRyear_AICTmp.at(t) << ";" <<
                 theClimateModelDallara.total_annual_radiative_forcing.at(t) << ";";
            for (unsigned int i = 0; i <= 7; i++) {
                plot << theClimateModelDallara.annual_radiative_forcing.at(i).at(t) << ";";
            }
            plot << theClimateModelDallara.total_annual_normalized_radiative_forcing.at(t) << ";";
            for (unsigned int i = 0; i <= 7; i++) {
                plot << theClimateModelDallara.annual_normalized_radiative_forcing.at(i).at(t) << ";";
            }
            plot << theClimateModelDallara.total_annual_agwp.at(t) << ";";
            for (unsigned int i = 0; i <= 7; i++) {
                plot << theClimateModelDallara.annual_agwp.at(i).at(t) << ";";
            }
            plot << theClimateModelDallara.total_annual_temperature_change.at(t) << ";";
            for (unsigned int i = 0; i <= 7; i++) {
                plot << theClimateModelDallara.annual_temperature_change.at(i).at(t) << ";";
            }
            plot << theClimateModelDallara.total_annual_temperature_change_weighted.at(t) << ";";
            for (unsigned int i = 0; i <= 7; i++) {
                plot << theClimateModelDallara.annual_temperature_change_weighted.at(i).at(t) << ";";
            }
            plot << theClimateModelDallara.total_annual_agtp.at(t) << ";";
            for (unsigned int i = 0; i <= 7; i++) {
                plot << theClimateModelDallara.annual_agtp.at(i).at(t) << ";";
            }
            plot << e_year_CO2Tmp.at(t) << ";" <<
                 e_year_NOxTmp.at(t) << ";" <<
                 e_year_H2OTmp.at(t) << ";" <<
                 e_year_sootTmp.at(t) << ";" <<
                 e_year_SO4Tmp.at(t) << ";" <<
                 e_year_AICTmp.at(t) << ";" <<
                 std::endl;
        }
        plot.close();
    }
}
