/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "bwbVerticalTailsDesignConfig.h"

#include <aircraftGeometry2/airfoil_surface.h>

namespace bwb {
namespace low {
VerticalTailsConfig::VerticalTailsConfig()
    : design_mode(EndnodeReadOnly<std::string>("module_configuration_file/program_settings/modes/design_mode")),
      mass_mode(EndnodeReadOnly<std::string>("module_configuration_file/program_settings/modes/mass_mode/method")),
      mass_mode_flops_technology_factor(EndnodeReadOnly<double>("module_configuration_file/program_settings/modes/mass_mode/parameters/mode_0/technology_factor")),
      common_airfoil_data_path(EndnodeReadOnly<std::string>("module_configuration_file/program_settings/common_airfoil_data_path")) {}

void VerticalTailsConfig::read(const node& xml) {
  design_mode.read(xml);
  mass_mode.read(xml);
  mass_mode_flops_technology_factor.read(xml);
  common_airfoil_data_path.read(xml);

  /* List all tail elements */
  std::string path_to_tail_elements =
      "module_configuration_file/program_settings/blended_wing_body/low_fidelity/vertical_tails/tail_element";
  std::vector<node*> tail_elements = xml.getVector(path_to_tail_elements, 1);
  for (size_t id = 0; id < tail_elements.size(); ++id) {
    vertical_tails.push_back(TailElement(path_to_tail_elements + "@" + std::to_string(id) + "/"));
  }
  for (auto& vertical_tail : vertical_tails) {
    vertical_tail.read(xml);
  }
}
}  // namespace low
}  // namespace bwb
