/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "empennageDesign.h"

#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>

#include <iostream>
#include <vector>
#include <format>

#include "bwb/vertical_tails/low/lowBwbVerticalTailsDesign.h"
#include "taw/conventional/low/lowConventionalEmpennageDesign.h"
#include "taw/t_tail/low/low_t_tail_empennage_design.h"

EmpennageDesign::EmpennageDesign(const int argc, char *argv[], const std::string &toolName,
                                 const std::string &toolVersion)
    : Module(argc, argv, toolName, toolVersion) {
  std::string configuration = rtIO_->aircraft_configuration_type();
  std::string usedtype = EndnodeReadOnly<std::string>("requirements_and_specifications/design_specification/configuration/empennage_definition/empennage_type").read(rtIO_->acxml).value();
  std::string fidelity = EndnodeReadOnly<std::string>("program_settings/" + configuration + "/fidelity_selection").read(rtIO_->moduleConfig).value();
  /* Register existing strategies */
  /* tube and wing strategies */
  strategy.registerStrategy<taw::low::Conventional>({"tube_and_wing", "conventional", "low"});
  strategy.registerStrategy<taw::low::T_Tail>({"tube_and_wing", "t_tail", "low"});

  /* blended wing body strategies*/
  strategy.registerStrategy<bwb::low::VerticalTails>({"blended_wing_body", "vertical_tails", "low"});

  /* Set desired strategy */
  strategy.setStrategy({configuration, usedtype, fidelity}, rtIO_);
}
