# UNICADO - UNIversity Conceptual Aircraft Design and Optimization
#
# Copyright (C) 2025 UNICADO consortium
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
# Description:
# This file is part of UNICADO.

def cabin_floor_thickness_calculation(geometry_description, runtime_output):
    """ Calculates cabin floor thickness from given cabin wall thickness.

        References and calculation method:
            [1] Prof. Dr.-Ing. Juergen Thorbeck TU-Berlin (2006), Script "Flugzeugentwurf I und II" page: XYZ
                cabin_floor_thickness = 1.5 * wall_thickness [inch]

    :param dict geometry_description: Dict containing geometry parameter and values of current fuselage design
    :param logging.Logger runtime_output: Logging object used for capturing log messages in the module
    :return dict geometry_description: Dict containing geometry parameter and values of current fuselage design
    """

    # Calculation of cabin floor thickness according to [1].
    geometry_description['cabin_floor_thickness'] = round(1.5 * geometry_description['cabin_wall_thickness'], 2)

    ''' debug print '''
    runtime_output.debug('Debug: The cabin_floor_thickness_calculation function was successfully executed!')

    return geometry_description
