/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef INITIAL_SIZING_SRC_BWB_BWBINITIALSIZINGCONFIG_H_
#define INITIAL_SIZING_SRC_BWB_BWBINITIALSIZINGCONFIG_H_

#include <string>
#include <vector>
#include <memory>
#include <moduleBasics/runtimeIO.h>  // NOLINT
#include "../toolinfo.h"

/* STANDARD SYSTEMS DESIGN CONFIG */
/**
 * \brief Storage class for non system specific values from configuration xml
 * 
 */
class BwbInitialSizingConfig {
 public:
    BwbInitialSizingConfig() {}

    void readAll(const node& config) {
        readProgramSettings(config);
    }

    double wing_loading_user = 0.; /**< Wing loading set by the user to be used in design [kg/m^2] */
    double thrust_loading_user = 0.; /**< Thrust loading set by the user to be used in design [-] */
    double maximum_takeoff_mass_user = 0.; /**< Maximum takeoff mass set by the user to be used in design [kg] */
    double operating_mass_empty_user = 0.; /**< Operating mass empty set by the user to be used in design [kg] */

 private:
    void readProgramSettings(const node& config);
};

#endif  // INITIAL_SIZING_SRC_BWB_BWBINITIALSIZINGCONFIG_H_
