/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef INITIALSIZING_SRC_BWBINITIALSIZINGDATA_H_  // NOLINT
#define INITIALSIZING_SRC_BWBINITIALSIZINGDATA_H_

#include <tuple>
#include <map>
#include <memory>
#include <string>
#include <vector>

namespace fs = std::filesystem;

/**
 * \brief storage class for acxml data and updating
*/
class BwbInitialSizingData {
 public:
    /**
     * @brief Create a endnode object and set its properties.
     * 
     * @tparam T The value type of the endnode.
     * @param value The value of the endnode.
     * @param node_path The location in the parent node of the endnode.
     * @param description The description of the endnode.
     * @return Endnode<T> Return the created endnode.
     */
    template<typename T>
    auto create_endnode(const T value, const std::string& node_path, const std::string& description) -> Endnode<T> {
        /* Create the node an set its properties */
        Endnode<T> new_node{node_path, description};
        new_node.set_value(value);
        /* Return the new node */
        return new_node;
    };

    /**
     * @brief Create a endnode object and set its properties.
     * 
     * @tparam T The value type of the endnode.
     * @param value The value of the endnode.
     * @param unit The unit of the endnode.
     * @param node_path The location in the parent node of the endnode.
     * @param description The description of the endnode.
     * @return Endnode<T> Return the created endnode.
     */
    template<typename T>
    auto create_endnode(const T value, const std::string& unit, const std::string& node_path, const std::string& description) -> Endnode<T> {
        /* Create the node an set its properties */
        Endnode<T> new_node{node_path, description};
        new_node.set_value(value);
        new_node.set_unit(unit);
        /* Return the new node */
        return new_node;
    };
};

#endif // INITIALSIZING_SRC_BWBINITIALSIZINGDATA_H_  // NOLINT
