/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include <iostream>
#include <memory>
#include <string>
#include "BwbAnalytical.h"
#include "../BwbInitialSizingIOData.h"
#include "../../initialSizingDefines.h"
#include <standardFiles/functions.h>

BwbAnalytical::BwbAnalytical(std::shared_ptr<RuntimeIO> rtIO) : rtIO_(rtIO), report_(rtIO) {}

void BwbAnalytical::initialize() {
    const node& config = rtIO_->moduleConfig;
    /* Initializing IOData */
    data_ = std::make_shared<BwbInitialSizingIOData>(rtIO_, config);
}

void BwbAnalytical::run() {
    std::stringstream errorMessage;
    errorMessage << "For blended_wing_body configuration, the analytical model is not yet implemented." << std::endl;
    errorMessage << "You can use the read_only method in configuration file. Abort program." << std::endl;
    throwError(__FILE__, __FUNCTION__, __LINE__, errorMessage.str());
}

void BwbAnalytical::update() {
}

void BwbAnalytical::report() {
}

void BwbAnalytical::save() {
}
