/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include <iostream>
#include <memory>
#include <string>
#include "TawReadonly.h"
#include "../TawInitialSizingIOData.h"
#include "../../initialSizingDefines.h"
#include <standardFiles/functions.h>

TawReadonly::TawReadonly(std::shared_ptr<RuntimeIO> rtIO) : rtIO_(rtIO), report_(rtIO) {}

void TawReadonly::initialize() {
    const node& config = rtIO_->moduleConfig;
    /* Initializing IOData */
    data_ = std::make_shared<TawInitialSizingIOData>(rtIO_, config);
}

void TawReadonly::run() {
    myRuntimeInfo->out << "Initial sizing is running in TAW/Readonly Mode. "
                       << "The values from config will be written to aircraft exchange file." << std::endl;
}

void TawReadonly::update() {
    data_->setGlobalReferencePoint();
    data_->updateTW(data_->configuration.thrust_loading_user);
    data_->updateWS(data_->configuration.wing_loading_user);
    data_->updateMTOM(data_->configuration.maximum_takeoff_mass_user);
    data_->updateOME(data_->configuration.operating_mass_empty_user);
}

void TawReadonly::report() {
}

void TawReadonly::save() {
}
