/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 * 
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */
#ifndef PERFORMANCE_ASSESSMENT_SRC_TAW_DEFAULTMETHODS_TAKEOFFPERFORMANCE_ABSTRACTTAKEOFFPERFORMANCE_H_
#define PERFORMANCE_ASSESSMENT_SRC_TAW_DEFAULTMETHODS_TAKEOFFPERFORMANCE_ABSTRACTTAKEOFFPERFORMANCE_H_

#include <vector>

class abstractTakeOffPerformance {
 public:
    /**\class dataTOFL class contains informations about the take-off field length
    *
    */
    class dataTOFL {
     public:
        double TODR_AEO; /**< Take-off distance required with all engines operating (m) */
        double Time; /**< Time (s) */
        double grossMass; /**< Aircraft gross mass (kg) */

        dataTOFL() {
            grossMass = 0.0;
            TODR_AEO = 0.0;
            Time = 0.0;
        }
    };
    /**\class dataElevationTOFL class contains airfield elevation data
    *
    */
    class dataElevationTOFL {
     public:
        double elevation; /**< Elevation of the airfield (m) */
        std::vector<dataTOFL> myTOFL; /**< List of take-off field length data (Aircraft mass, Take-off distance, Time) */

        dataElevationTOFL() {
            elevation  = 0.0;
        }
    };
    std::vector<dataElevationTOFL> myTOFLField;  /**< List of airfield elevation data */

    /**\class dataBLFL class contains data for the balanced field length
    *
    */
    class dataBLFL {
     public:
        double grossMass; /**< Aircraft mass (kg) */
        double v1; /**< Decision speed (m/s) */
        double BLFL; /**< Balanced field length (m) */
        double TODR_AEO; /**< Take-off distance required with all engines operating (m) */
        std::vector<double> vEF; /**< Engine failure speed (m/s) */
        std::vector<double> TODR_OEI; /**< Take-off distance required with one engine operative (m) */
        std::vector<double> ASDR_OEI; /**< Accelerate stop distance required with one engine inoperative (m) */

        dataBLFL() {
            grossMass = 0.0;
            v1 = 0.;
            BLFL = 0.0;
            TODR_AEO = 0.0;
        }
    };
    dataBLFL myBLFL;

    double scdSegmentGradient; /**< Climb or descend gradient of the second segment (%) */
    double finalSegmentGradient; /**< Descend gradient of the final segment (%) */


    virtual ~abstractTakeOffPerformance() { }
    virtual void doTakeOffPerformance(double theRunwaySlope, double theGroundFriction, double theGroundFrictionBraking, double theHeadWind) = 0;
    virtual void calcBLFL(double theRunwaySlope, double theGroundFriction, double theGroundFrictionBraking, double theHeadWind) = 0;
};

#endif  // PERFORMANCE_ASSESSMENT_SRC_TAW_DEFAULTMETHODS_TAKEOFFPERFORMANCE_ABSTRACTTAKEOFFPERFORMANCE_H_
