/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef SYSTEMS_DESIGN_SRC_COMMON_AIRCRAFTSYSTEMS_WINGANTIICING_LIQUIDWATERCONTENT_H_
#define SYSTEMS_DESIGN_SRC_COMMON_AIRCRAFTSYSTEMS_WINGANTIICING_LIQUIDWATERCONTENT_H_

/** \brief Contains all properties for calculation of the liquid water content
 */
class liquidWaterContent {
 public:
    /** \brief calculates the LWC for maximum icing conditions
     *
     * \param TemperatureCelsius double: [degC]
     * \param dropDiameterMikroMeter double: [micro meter]
     * \param cloudExtensionNauticalMiles double: [nm]
     * \return double: liquid water content
     *
     */
    double getLiquidWaterContentForMaximumIcing(double TemperatureCelsius, double dropDiameterMikroMeter, double cloudExtensionNauticalMiles);

    /** \brief calculates the LWC for intermittent icing conditions
     *
     * \param TemperatureCelsius double: [degC]
     * \param dropDiameterMikroMeter double: [micro meter]
     * \param cloudExtensionNauticalMiles double: [nm]
     * \return double: liquid water content
     *
     */
    double getLiquidWaterContentForIntermittentIcing(double TemperatureCelsius, double dropDiameterMikroMeter, double cloudExtensionNauticalMiles);

    /** \brief calculates the LWC for maximum takeoff conditions
     *
     * \return double: liquid water content
     *
     */
    double getLiquidWaterContentForMaxTakeOff();

    liquidWaterContent();
    virtual ~liquidWaterContent();
};

#endif //SYSTEMS_DESIGN_SRC_COMMON_AIRCRAFTSYSTEMS_WINGANTIICING_LIQUIDWATERCONTENT_H_
