/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "virtualSystemsDesign.h"
#include "../toolinfo.h"
#include <vector>

void virtual_systems_design::set_html_body() {
    std::string plot_path = relativePath(rtIO_->getPlotDir(), rtIO_->getReportDir()) + "/" + data_->configuration.theProgramName;
    /* Add box data */
    report_.htmlReportStream() << "<div class=\"box data\">\n";
    /* Add headline Data*/
    report_.htmlReportStream() << "<caption>Program Mode: </caption>";
    if (data_->configuration.designCase == true) {
       report_.htmlReportStream() << "Sizing Mode" << std::endl;
    } else {
       report_.htmlReportStream() << "Analysis Mode" << std::endl;
    }
    report_.htmlReportStream() << "<h2>Systems Masses</h2>" << std::endl;
    if (data_->configuration.designCase == true) {
        report_.htmlReportStream() << "<div id=\"leftCol\">" << std::endl
                                << "<table>" << std::endl
                                << "<tr>" << std::endl;
                                for (size_t i = 0; i < data_->Systems.virtualSystem.size(); i++) {
                                    report_.htmlReportStream() << std::setprecision(4) << "<td>"
                                    << data_->Systems.virtualSystem.at(i)->ATA << "</td><td>"
                                    << data_->Systems.virtualSystem.at(i)->Name << "</td><td>"
                                    << data_->Systems.virtualSystem.at(i)->Mass
                                    << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                }
                                report_.htmlReportStream() << "<td><h2>Operator Items</h2></td>" << std::endl
                                << "</tr>" << std::endl
                                << "<tr>" << std::endl
                                << "<td>---</td><td>Op. items calc. in systemsDesign (liquid)</td><td>"
                                << data_->data.Mass.waterAndChemicalsMass + data_->data.Mass.residualFuelMass
                                << " kg</td>" << std::endl
                                << "</tr>" << std::endl
                                << "<tr>" << std::endl
                                << "<td></td>" << std::endl
                                << "</tr>" << std::endl
                                << "<tr>" << std::endl
                                << "</tr>" << std::endl
                                << "</table>" << std::endl
                                << "</div>" << std::endl;
    } else {
        report_.htmlReportStream() << "<td>The program was run in analysis mode..</td>" << std::endl
                                << "<td>The masses were not redetermined!</td>" << std::endl;
    }
    /* Mission Profile Section */
    report_.htmlReportStream() << "<div id=\"wrapper\">" << std::endl
    << "<div id=\"leftCol\">" << std::endl
    << "<h2>Required Power during the Mission</h2>" << std::endl
    << "<font size=\"-1\">Values at the end of the mission step are given in each case.</font>" << std::endl
    << "<img class=\"image-plot\" src=\"" + plot_path + "_mission_steps_plot.svg\">" << std::endl
    << "<img class=\"image-plot\" src=\"" + plot_path + "_virtual_accumulated_power_plot.svg\">" << std::endl
    << "</div>" << std::endl
    << "<div id=\"rightCol\">" << std::endl
    << "</div>\n"
    << "<!-- ################################################################################################### -->" << std::endl;
}
