# UNICADO - UNIversity Conceptual Aircraft Design and Optimization
#
# Copyright (C) 2025 UNICADO consortium
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
# Description:
# This file is part of UNICADO.

"""Transport task IO"""


class TransportTaskIO:
    def __init__(self) -> None:
        self.number_of_passengers = None
        self.mass_per_passenger = None
        self.luggage_mass_per_passenger = None
        self.additional_cargo_mass = None
        self.cargo_density = None
        self.class_president = None
        self.class_first = None
        self.class_business = None
        self.class_premium_economy = None
        self.class_economy = None

    def read(self, xml_node):
        base_path = "./requirements_and_specifications/design_specification/transport_task/"
        self.number_of_passengers = int(xml_node.find(
            base_path + "passenger_definition/total_number_passengers/value").text)
        self.mass_per_passenger = float(xml_node.find(
            base_path + "passenger_definition/mass_per_passenger/value").text)
        self.luggage_mass_per_passenger = float(xml_node.find(
            base_path + "passenger_definition/luggage_mass_per_passenger/value").text)
        self.additional_cargo_mass = float(xml_node.find(
            base_path + "cargo_definition/additional_cargo_mass/value").text)
        self.cargo_density = float(xml_node.find(
            base_path + "cargo_definition/cargo_density/value").text)

        # Class distribution
        tmp = str(xml_node.find(
            base_path + "passenger_class_definition/class_distribution/value").text).split("/")
        self.class_president = tmp[0]
        self.class_first = tmp[1]
        self.class_business = tmp[2]
        self.class_premium_economy = tmp[3]
        self.class_economy = tmp[4]

        return self

    @property
    def passenger_mass(self):
        return self.mass_per_passenger * self.number_of_passengers

    @property
    def luggage_mass(self):
        return self.luggage_mass_per_passenger * self.number_of_passengers

    @property
    def combined_passenger_and_luggage_mass(self):
        return self.luggage_mass + self.passenger_mass
